@@ -9,7 +9,6 @@ import pickle
 import shutil
 import sys
 import threading
-import zlib
 from typing import (
     Any,
     Callable,
@@ -22,6 +21,7 @@ from typing import (
     TypeVar,
     cast,
 )
+import zlib
 
 from .types import PathLike, RLockLike, Serializable, Serializer, UserDict
 from .util import (
@@ -163,6 +163,12 @@ class Cache(Generic[CacheFunc]):
         verbose: bool = False,
         use_module_name: bool = True,
     ) -> None:
+        self.logger = logging.getLogger("charmonium.cache").getChild(__name__)
+        self.logger.setLevel(logging.DEBUG)
+        self.handler = logging.StreamHandler(sys.stderr)
+        self.handler.setFormatter(logging.Formatter("%(asctime)s - %(message)s"))
+        if verbose:
+            self.enable_logging()
         self.function = function
         if name:
             self.name = name
@@ -171,12 +177,6 @@ class Cache(Generic[CacheFunc]):
                 self.name = f"{self.function.__module__}.{self.function.__qualname__}"
             else:
                 self.name = self.function.__qualname__
-        self.logger = logging.getLogger("charmonium.cache").getChild(self.name)
-        self.logger.setLevel(logging.DEBUG)
-        self.handler = logging.StreamHandler(sys.stderr)
-        self.handler.setFormatter(logging.Formatter("%(asctime)s - %(message)s"))
-        if verbose:
-            self.enable_logging()
         self.obj_store = obj_store(self.name, self.logger)
         self.lock = lock
         self.state_fn = state_fn
@@ -195,12 +195,12 @@ class Cache(Generic[CacheFunc]):
                     old_state, res = self.obj_store[args_key]
                     if old_state == state:
                         self.logger.getChild("hit").debug(
-                            "%s: hit with args: %.30s, %.30s", self.name, pos_args, kwargs
+                            "%s: hit with args: %s, %s", self.name, pos_args, kwargs
                         )
                         return res
                     else:
                         self.logger.getChild("miss").debug(
-                            "%s: miss with args: %.30s, %.30s due to state (%.30s -> %.30s)",
+                            "%s: miss with args: %s, %s due to state (%s -> %s)",
                             self.name,
                             pos_args,
                             kwargs,
@@ -211,7 +211,7 @@ class Cache(Generic[CacheFunc]):
                         self.obj_store[args_key] = state, res
                 else:
                     self.logger.getChild("miss").debug(
-                        "%s: miss with %.30s, %.30s", self.name, pos_args, kwargs
+                        "%s: miss with %s, %s", self.name, pos_args, kwargs
                     )
                     res = self.function(*pos_args, **kwargs)
                     self.obj_store[args_key] = state, res
